##  Navigating Between SAP LeanIX and SAP Cloud ALM
Linking an SAP Cloud ALM project to an SAP LeanIX fact sheet allows you to easily move between both systems, making it simpler to manage and access all relevant project information.
In the Agile Tracking tab of the connected initiative fact sheet, click Open in SAP Cloud ALM to open the associated project directly in SAP Cloud ALM. Similarly, in the SAP Cloud ALM, you can find the link to the connected fact sheet under the External Integration section in the General Information tab of the project.
![Accessing SAP LeanIX Fact Sheet from SAP Cloud ALM Project](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ce3087a4410148687c33db0c9dced_LowRes.png)
Accessing SAP LeanIX Fact Sheet from SAP Cloud ALM Project
YesNo
Send
